/*
Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
Copyright (C) 2005- The University of Notre Dame
This software is distributed under a BSD-style license.
See the file COPYING for details.
*/

#ifndef LINK_H
#define LINK_H

#include "int_sizes.h"

#include <time.h>
#include <limits.h>
#include <stdio.h>
#include <sys/types.h>

/* Maximum number of characters in a link address */
#define LINK_ADDRESS_MAX 17

/* Value to usewhen any listen port is acceptable */
#define LINK_PORT_ANY 0

/* Stoptime to give when you wish to wait forever */
#define LINK_FOREVER ((time_t)INT_MAX)

struct link * link_attach( int fd );
struct link * link_serve( int port );
struct link * link_accept( struct link *master, time_t stoptime );
struct link * link_connect( const char *addr, int port, time_t stoptime );

int  link_read( struct link *link, char *data, int length, time_t stoptime );
int  link_write( struct link *link, const char *data, int length, time_t stoptime );
int  link_sleep( struct link *link, time_t stoptime, int reading, int writing );
int  link_usleep( struct link *link, int usec, int reading, int writing );
void link_close( struct link *link );
int  link_fd( struct link *link );

int  link_readline( struct link *link, char *line, int length, time_t stoptime );
int  link_nonblocking( struct link *link, int onoff );

int  link_address_local( struct link *link, char *addr, int *port );
int  link_address_remote( struct link *link, char *addr, int *port );

INT64_T link_stream_to_buffer( struct link *link, char **buffer, time_t stoptime );

INT64_T link_stream_to_fd( struct link *link, int fd, INT64_T length, time_t stoptime );
INT64_T link_stream_to_file( struct link *link, FILE *file, INT64_T length, time_t stoptime );

INT64_T link_stream_from_fd( struct link *link, int fd, INT64_T length, time_t stoptime );
INT64_T link_stream_from_file( struct link *link, FILE *file, INT64_T length, time_t stoptime );

INT64_T link_soak( struct link *link, INT64_T length, time_t stoptime );

typedef enum {
	LINK_TUNE_INTERACTIVE,
	LINK_TUNE_BULK
} link_tune_t;

int  link_tune( struct link *link, link_tune_t mode );

#endif













