/*
Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
Copyright (C) 2005- The University of Notre Dame
This software is distributed under a BSD-style license.
See the file COPYING for details.
*/

#include "rotating_file.h"
#include "macros.h"
#include "full_io.h"

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <stdarg.h>
#include <alloca.h>
#include <fcntl.h>

#define BUFFER_SIZE 1024

int rotating_file_vprintf( const char *path, int maxsize, const char *fmt, va_list args )
{
	char buffer[BUFFER_SIZE];
	int length;

	length = vsnprintf(buffer,BUFFER_SIZE,fmt,args);
	buffer[BUFFER_SIZE-1] = 0;
	length = MIN(length,BUFFER_SIZE-1);

	return rotating_file_write(path,maxsize,buffer,length);
}

int rotating_file_write( const char *path, int maxsize, const char *data, int length )
{
	int fd;
	int size;

	fd = open(path,O_CREAT|O_APPEND|O_WRONLY,0777);
	if(fd<0) return 0;

	size = lseek(fd,0,SEEK_END);

	full_write(fd,data,length);

	if(maxsize!=0) {
		if( size > maxsize ) {
			char *newname = alloca(strlen(path)+5);
			sprintf(newname,"%s.old",path);
			rename(path,newname);
			full_write(fd,"*** rotating file ***\n",23);
		}
	}

	close(fd);
	return 1;
}


